@@ -71,6 +71,45 @@ impl std::str::FromStr for StudentSortCriteria {
     }
 }
 
+/// Enumeration of values.
+/// Since this enum's variants do not hold data, we can easily define them them as `#[repr(C)]`
+/// which helps with FFI.
+#[allow(non_camel_case_types)]
+#[repr(C)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, serde::Serialize, serde::Deserialize)]
+#[cfg_attr(feature = "conversion", derive(frunk_enum_derive::LabelledGenericEnum))]
+pub enum StudentTitle {
+    #[serde(rename = "PRIEST")]
+    PRIEST,
+    #[serde(rename = "MONK")]
+    MONK,
+    #[serde(rename = "NUN")]
+    NUN,
+}
+
+impl std::fmt::Display for StudentTitle {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match *self {
+            StudentTitle::PRIEST => write!(f, "{}", "PRIEST"),
+            StudentTitle::MONK => write!(f, "{}", "MONK"),
+            StudentTitle::NUN => write!(f, "{}", "NUN"),
+        }
+    }
+}
+
+impl std::str::FromStr for StudentTitle {
+    type Err = String;
+
+    fn from_str(s: &str) -> std::result::Result<Self, Self::Err> {
+        match s {
+            "PRIEST" => std::result::Result::Ok(StudentTitle::PRIEST),
+            "MONK" => std::result::Result::Ok(StudentTitle::MONK),
+            "NUN" => std::result::Result::Ok(StudentTitle::NUN),
+            _ => std::result::Result::Err(format!("Value not valid: {}", s)),
+        }
+    }
+}
+
 /// Student info
 #[derive(Debug, Clone, PartialEq, serde::Serialize, serde::Deserialize)]
 #[cfg_attr(feature = "conversion", derive(frunk::LabelledGeneric))]
@@ -84,10 +123,9 @@ pub struct StudentUpsert {
     #[serde(skip_serializing_if="Option::is_none")]
     pub saint_id_array: Option<Vec<uuid::Uuid>>,
 
-    // Note: inline enums are not fully supported by openapi-generator
     #[serde(rename = "title")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub title: Option<String>,
+    pub title: Option<models::StudentTitle>,
 
     #[serde(rename = "firstName")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -152,11 +190,7 @@ impl std::string::ToString for StudentUpsert {
 
         // Skipping saintIdArray in query parameter serialization
 
-
-        if let Some(ref title) = self.title {
-            params.push("title".to_string());
-            params.push(title.to_string());
-        }
+        // Skipping title in query parameter serialization
 
 
         if let Some(ref first_name) = self.first_name {
@@ -218,7 +252,7 @@ impl std::str::FromStr for StudentUpsert {
         struct IntermediateRep {
             pub polity_id: Vec<uuid::Uuid>,
             pub saint_id_array: Vec<Vec<uuid::Uuid>>,
-            pub title: Vec<String>,
+            pub title: Vec<models::StudentTitle>,
             pub first_name: Vec<String>,
             pub middle_name: Vec<String>,
             pub last_name: Vec<String>,
@@ -245,7 +279,7 @@ impl std::str::FromStr for StudentUpsert {
                 match key {
                     "polityId" => intermediate_rep.polity_id.push(<uuid::Uuid as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "saintIdArray" => return std::result::Result::Err("Parsing a container in this style is not supported in StudentUpsert".to_string()),
-                    "title" => intermediate_rep.title.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "title" => intermediate_rep.title.push(<models::StudentTitle as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "firstName" => intermediate_rep.first_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "middleName" => intermediate_rep.middle_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "lastName" => intermediate_rep.last_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
@@ -346,10 +380,9 @@ pub struct StudentView {
     #[serde(skip_serializing_if="Option::is_none")]
     pub christian_name: Option<String>,
 
-    // Note: inline enums are not fully supported by openapi-generator
     #[serde(rename = "title")]
     #[serde(skip_serializing_if="Option::is_none")]
-    pub title: Option<String>,
+    pub title: Option<models::StudentTitle>,
 
     #[serde(rename = "name")]
     #[serde(skip_serializing_if="Option::is_none")]
@@ -436,11 +469,7 @@ impl std::string::ToString for StudentView {
             params.push(christian_name.to_string());
         }
 
-
-        if let Some(ref title) = self.title {
-            params.push("title".to_string());
-            params.push(title.to_string());
-        }
+        // Skipping title in query parameter serialization
 
 
         if let Some(ref name) = self.name {
@@ -494,7 +523,7 @@ impl std::str::FromStr for StudentView {
             pub polity_location_address: Vec<String>,
             pub polity_location_email: Vec<String>,
             pub christian_name: Vec<String>,
-            pub title: Vec<String>,
+            pub title: Vec<models::StudentTitle>,
             pub name: Vec<String>,
             pub date_of_birth: Vec<chrono::DateTime::<chrono::Utc>>,
             pub place_of_birth: Vec<String>,
@@ -523,7 +552,7 @@ impl std::str::FromStr for StudentView {
                     "polityLocationAddress" => intermediate_rep.polity_location_address.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "polityLocationEmail" => intermediate_rep.polity_location_email.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "christianName" => intermediate_rep.christian_name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
-                    "title" => intermediate_rep.title.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "title" => intermediate_rep.title.push(<models::StudentTitle as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "name" => intermediate_rep.name.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "dateOfBirth" => intermediate_rep.date_of_birth.push(<chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     "placeOfBirth" => intermediate_rep.place_of_birth.push(<String as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
